Overview
--------
For now the library is still tiny. Functionality gets added or refined 
as needed, as of yet we have basically: 

* the caching and concurrency helper decorators.
* a config parser wrapper with fallback support in getters
* finder for files placed in typical configuration storage places

.. toctree::
   :maxdepth: 2

   decorators
   lck.files
   lck.config
